pub(crate) struct ConfiguredLoginParam {
pub addr: String,
pub imap: Vec<ConfiguredServerLoginParam>,
pub imap_user: String,
pub imap_password: String,
pub imap_folder: Option<String>,
pub smtp: Vec<ConfiguredServerLoginParam>,
pub smtp_user: String,
pub smtp_password: String,
pub provider: Option<&'static Provider>,
pub certificate_checks: ConfiguredCertificateChecks,
pub oauth2: bool,
}Expand description
Login parameters saved to the database after successful configuration.
Fields
addr: StringFrom: address that was used at the time of configuration.
imap: Vec<ConfiguredServerLoginParam>List of IMAP candidates to try.
imap_user: StringCustom IMAP user.
This overwrites autoconfig from the provider database if non-empty.
imap_password: Stringimap_folder: Option<String>smtp: Vec<ConfiguredServerLoginParam>List of SMTP candidates to try.
smtp_user: StringCustom SMTP user.
This overwrites autoconfig from the provider database if non-empty.
smtp_password: Stringprovider: Option<&'static Provider>certificate_checks: ConfiguredCertificateChecksTLS options: whether to allow invalid certificates and/or invalid hostnames
oauth2: boolIf true, login via OAUTH2 (not recommended anymore)
Implementations
Sourceimpl ConfiguredLoginParam
impl ConfiguredLoginParam
Sourcepub(crate) async fn load(context: &Context) -> Result<Option<(u32, Self)>>
pub(crate) async fn load(context: &Context) -> Result<Option<(u32, Self)>>
Load configured account settings from the database.
Returns transport ID and configured parameters
of the current primary transport.
Returns None if account is not configured.
Sourcepub(crate) async fn load_all(context: &Context) -> Result<Vec<(u32, Self)>>
pub(crate) async fn load_all(context: &Context) -> Result<Vec<(u32, Self)>>
Loads configured login parameters for all transports.
Returns a vector of all transport IDs paired with the configured parameters for the transports.
Sourcepub(crate) async fn load_legacy(context: &Context) -> Result<Option<Self>>
pub(crate) async fn load_legacy(context: &Context) -> Result<Option<Self>>
Loads legacy configured param. Only used for tests and the migration.
pub(crate) async fn save_to_transports_table( self, context: &Context, entered_param: &EnteredLoginParam, timestamp: i64, ) -> Result<()>
pub(crate) fn from_json(json: &str) -> Result<Self>
pub(crate) fn into_json(self) -> Result<String>
pub(crate) fn strict_tls(&self, connected_through_proxy: bool) -> bool